@@ -16,11 +16,12 @@ class DefaultLocalesChoices(models.TextChoices):
 
 class BaseMessage(models.Model):
     id = models.CharField(max_length=255, primary_key=True)
-    default = models.TextField(
-        verbose_name="Default singular form of the message",
-    )
-    default_plural = models.TextField(
-        verbose_name="Default plural form of the message",
+    default = models.TextField(verbose_name="Default singular form")
+    default_plural = models.TextField(verbose_name="Default plural form")
+    context = models.CharField(
+        max_length=1024,
+        default="",
+        blank=True,
     )
     is_used = models.BooleanField(verbose_name="Is used", default=True)
 
