@@ -88,24 +88,15 @@ class DjangoStorage(BaseStorage):
                 "Message '%s' is new, adding to the database...",
                 message,
             )
-            new_messages.add(
-                self.message_model(
-                    id=message.id,
-                    default=message.default,
-                    default_plural=message.default_plural,
-                ),
-            )
+            new_messages.add(self._init_message_model(message))
             self.storage[message.id] = message
 
         await self.message_model.objects.abulk_create(new_messages)
         updated_messages_count: int = (
+            # pyright: reportGeneralTypeIssues=false
             await self.message_model.objects.abulk_update(
                 (
-                    self.message_model(
-                        id=message.id,
-                        default=message.default,
-                        default_plural=message.default_plural,
-                    )
+                    self._init_message_model(message)
                     for message in self.storage.values()
                 ),
                 fields=("default", "default_plural"),
@@ -121,3 +112,14 @@ class DjangoStorage(BaseStorage):
             len(new_messages),
             len(unused_messages),
         )
+
+    def _init_message_model(
+        self,
+        storage_message: StorageMessage,
+    ) -> BaseMessage:
+        return self.message_model(
+            id=storage_message.id,
+            default=storage_message.default,
+            default_plural=storage_message.default_plural,
+            context=storage_message.context,
+        )
